@@ -1,6 +1,8 @@
 from typing import Type, Dict, List, Any, TypeVar, Generic
 from uuid import UUID
 
+from pymongo import ReturnDocument
+
 from deci_common.abstractions.base_model import DBSchema
 from deci_common.data_connection.mongo_db_connector import MongoDBConfiguration, MongoDBConnector
 from deci_common.abstractions.abstract_logger import ILogger
@@ -43,7 +45,9 @@ class DBInterface(Generic[T], ILogger):
         @return: T
         """
         with self._db_connector as db:
-            updated_element = db._update_document(search_filter={"id": element.id}, updated_document=element.dict())
+            updated_element = db._update_and_return_document(
+                search_filter={"id": element.id}, updated_document=element.dict(), return_document=ReturnDocument.AFTER
+            )
         return self._element_type(**updated_element.raw_result)
 
     def delete(self, id: UUID, force: bool = False) -> bool:
@@ -57,5 +61,7 @@ class DBInterface(Generic[T], ILogger):
             if force:
                 delete_result = db._delete_document(search_filter={"id": id})
                 return delete_result.deleted_count == 1
-            updated_element = db._update_document(search_filter={"id": id}, updated_document={"deleted": True})
-            return updated_element.raw_result["deleted"]
+            updated_element = db._update_and_return_document(
+                search_filter={"id": id}, updated_document={"deleted": True}, return_document=ReturnDocument.AFTER
+            )
+            return updated_element["deleted"]
